package videoautomat;

import sale.Gate;
import sale.SaleProcess;
import sale.SalesPoint;
import sale.UIGate;
import videoautomat.contentcreator.HandBackSTFSContentCreator;
import videoautomat.contentcreator.HandBackTTFSContentCreator;
import data.IntegerValue;
import data.MoneyBag;
import data.NumberValue;
import data.ooimpl.CatalogItemImpl;
import data.ooimpl.MoneyBagImpl;
import data.ooimpl.StockItemImpl;
import data.ooimpl.StoringStockImpl;
import data.stdforms.SingleTableFormSheet;
import data.stdforms.TwoTableFormSheet;
import data.stdforms.twotableformsheet.SSSSStrategy;

/**
 * This class implements a <code>SaleProcess</code> to hand back the videos.
 * @author Alexander Herrmann
 */
public class SaleProcessHandBack extends SaleProcess {

    /**
	 * ID for Serialization.
	 */
	private static final long serialVersionUID = -3003924365730438200L;

	/**
	 * StoringStock to store temporary videos
	 */
	private StoringStockImpl<StockItemImpl, CatalogItemImpl> temporaryVideosStoringStock;
	
	/**
	 * MoneyBag to temporarily store the change money
	 */
	private MoneyBag temporaryChangeMoneyBag;

	/**
	 * NumberValue representing the change money
	 */
	private NumberValue changeMoneyNumberValue;
	
	/**
	 * Constructs a new <code>SaleProcessHandBack</code>
	 * 
	 */
	public SaleProcessHandBack() {
		super("SaleProcessGiveback");
	}

	/**
	 * Implementation of the inherited abstract method.
	 * 
	 * @return the <code>Gate</code> where the user will see his/her current rented videos.
	 * @see sale.SaleProcess#getInitialGate()
	 * @author Alexander Herrmann
	 */
	protected Gate getInitialGate() {
	    
	    // generate Gate
	    UIGate uig_video = new UIGate(null, null);
	    
	    setTemporaryVideosStoringStock(new StoringStockImpl<StockItemImpl, CatalogItemImpl>("temp", VideoShop.getVideoCatalog()));
	    setTemporaryChangeMoneyBag(new MoneyBagImpl("temp", VideoShop.getCurrency()));
	    setChangeMoneyNumberValue(new IntegerValue(0));
	    
	    TwoTableFormSheet ttfs_handback =
	        TwoTableFormSheet.create(
	                "Give back a video",
	                ((AutomatUser) ((SalesPoint) this.getContext()).getUser()).getVideoStock(),
	                getTemporaryVideosStoringStock(),
	                getBasket(),
	                uig_video,
	                null,
	                null,
	                new TEDVideoCassette(),
	                new TEDVideoCassette(),
	                new SSSSStrategy(),
	                TwoTableFormSheet.RIGHT
	                );
	    
	    ttfs_handback.addContentCreator(new HandBackTTFSContentCreator());
	    
		return uig_video;
	}
	
	/**
	 * Returns the initial Gate.
	 * 
	 * @return initialGate
	 */
	public Gate restart()
	{
	    return getInitialGate();
	}

	/**
	 * @return the <code>Gate</code> where the user will see his/her change money.
	 * @author Alexander Herrmann
	 */
	public Gate getChangeGate() {
	    
	    // generate Gate
	    UIGate uig_change = new UIGate(null, null);
	    
	    SingleTableFormSheet stfs_change =
	        SingleTableFormSheet.create(
	                "Here is your change!",
	                getTemporaryChangeMoneyBag(),
	                uig_change,
	                getBasket());
	     
	    stfs_change.addContentCreator(new HandBackSTFSContentCreator(getChangeMoneyNumberValue()));
	    
		return uig_change;
	}

	/**
	 * Get the StoringStock to store temporary videos.
	 * @return the StoringStock to store temporary videos
	 */
	public StoringStockImpl<StockItemImpl, CatalogItemImpl> getTemporaryVideosStoringStock() {
		return temporaryVideosStoringStock;
	}

	/**
	 * Set the StoringStock to store temporary videos.
	 * @param temporaryVideosStoringStock the StoringStock to store temporary videos
	 */
	public void setTemporaryVideosStoringStock(StoringStockImpl<StockItemImpl, CatalogItemImpl> temporaryVideosStoringStock) {
		this.temporaryVideosStoringStock = temporaryVideosStoringStock;
	}

	/**
	 * Get the MoneyBag to temporarily store the change money.
	 * @return the MoneyBag to temporarily store the change money
	 */
	public MoneyBag getTemporaryChangeMoneyBag() {
		return temporaryChangeMoneyBag;
	}

	/**
	 * Set the MoneyBag to temporarily store the change money.
	 * @param temporaryChangeMoneyBag the MoneyBag to temporarily store the change money
	 */
	public void setTemporaryChangeMoneyBag(MoneyBag temporaryChangeMoneyBag) {
		this.temporaryChangeMoneyBag = temporaryChangeMoneyBag;
	}

	/**
	 * Get the NumberValue representing the change money.
	 * @return the NumberValue representing the change money
	 */
	public NumberValue getChangeMoneyNumberValue() {
		return changeMoneyNumberValue;
	}

	/**
	 * Set the NumberValue representing the change money.
	 * @param changeMoneyNumberValue the NumberValue representing the change money
	 */
	public void setChangeMoneyNumberValue(NumberValue changeMoneyNumberValue) {
		this.changeMoneyNumberValue = changeMoneyNumberValue;
	}

}
