package videoautomat.contentcreator;
import java.awt.Color;
import java.awt.Dimension;

import javax.swing.JLabel;
import javax.swing.JPasswordField;
import javax.swing.JTextArea;
import javax.swing.JTextField;

import sale.FormSheet;
import sale.FormSheetContentCreator;
import util.swing.JOptionPanel;
import videoautomat.contentcreator.stdactions.RollBackAction;
import videoautomat.contentcreator.stdactions.TransitWithAction;
import videoautomat.transition.RegisterOKTransition;

/**
 * Content creator of the register process. Contains methods to set and add data 
 * independly from the gui part.
 *
 * @author Tobias Ruch
 */
public class RegisterContentCreator extends FormSheetContentCreator {   

   /**
    * ID for Serialization.
	*/
   private static final long serialVersionUID = -5026365424912142706L;
   /** Textarea for the error message */
   private JTextArea errorMessage;
   /** Label with the initial massage */
   private JLabel message;
   /** Textfield for the user name */
   private JTextField userName;
   /** PasswordField for the 1st password */
   private JPasswordField password;
   /** PasswordField for the 2nd password */
   private JPasswordField confirmedPassword;   
   /**
    * Creates a new content creator with an initial message
    * @param message - initial message
    */
   public RegisterContentCreator(String message){
      
      //initialize components
      errorMessage      = new JTextArea();
      this.message      = new JLabel();
      userName          = new JTextField();
      password          = new JPasswordField();
      confirmedPassword = new JPasswordField();
      //set initial values
      this.message.setText(message);
      errorMessage.setForeground(Color.RED);
      errorMessage.setBackground(this.message.getBackground());
      errorMessage.setEditable(false);      
   }   
   
   /**
    * Method will be called from the FormSheet to which this ContentCreator is added.
    * So the Attribut fs will be this FormSheet.
    * You have to bild the content of your formsheet in this method
    * @param fs - FormSheet to which this ContentCreator was added.
    */
   protected void createFormSheetContent(FormSheet fs) {    
      JOptionPanel panel = new JOptionPanel(null, 16, 4, JOptionPanel.CENTER, JOptionPanel.CENTER);
      
      userName.setPreferredSize(new Dimension(150, 20));
      panel.addOption("User Name", userName);
      
      password.setPreferredSize(new Dimension(150, 20));
      panel.addOption("Password", password);
      
      confirmedPassword.setPreferredSize(new Dimension(150, 20));
      panel.addOption("Confirm Password", confirmedPassword);
      
      errorMessage.setPreferredSize(new Dimension(200, 50));
      panel.addOption("", errorMessage);
      fs.setComponent(panel);
      
      // set Buttons; using standard action to set transition classes
      fs.removeAllButtons();
      fs.addButton("OK", 1, new TransitWithAction(new RegisterOKTransition(this)));
      fs.addButton("Cancel", 2, new RollBackAction());      
   }   

   
   /**
    * Returns the value of the username.
    * @return - the username
    */
   public String getUserName(){
      return userName.getText();
   }
   
   /**
    * Returns the value of the password.
    * @return - the value of the password as an char array
    */
   public char[] getPassword(){
      return password.getPassword();
   }
   
   /**
    * Returns the value of the confirmed password.
    * @return - the value of the password as an char array
    */
   public char[] getConfirmedPassword(){
      return confirmedPassword.getPassword();
   }
   
   /**
    * Sets the value of the username
    * @param userName - value of the username
    */
   public void setUserName(String userName){
      this.userName.setText(userName);
   }
   
   /**
    * Sets the error message to this formsheet.
    * @param message - an error massage.
    */
   public void setErrorMessage(String message){
      errorMessage.setText(message);
   }   
   
}
